==> igniteui-react-charts-16.15.1.tgz: package/esm2015/lib/AbsoluteVolumeOscillatorIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { IShortPeriodLongPeriod_$type } from "./IShortPeriodLongPeriod";
import { AbsoluteVolumeOscillatorIndicatorStrategy } from "./AbsoluteVolumeOscillatorIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core";
/**
 * @hidden
 */
export let AbsoluteVolumeOscillatorIndicator = /*@__PURE__*/ (() => {
    class AbsoluteVolumeOscillatorIndicator extends StrategyBasedIndicator {
        get_t4() {
            return new AbsoluteVolumeOscillatorIndicatorStrategy();
        }
        get t4() {
            return this.get_t4();
        }
        get_uh() {
            return AbsoluteVolumeOscillatorIndicator.$;
        }
        get uh() {
            return this.get_uh();
        }
        get shortPeriod() {
            return typeGetValue(this.c(AbsoluteVolumeOscillatorIndicator.uq));
        }
        set shortPeriod(a) {
            this.h(AbsoluteVolumeOscillatorIndicator.uq, a);
        }
        uc() {
            return this.shortPeriod;
        }
        get longPeriod() {
            return typeGetValue(this.c(AbsoluteVolumeOscillatorIndicator.up));
        }
        set longPeriod(a) {
            this.h(AbsoluteVolumeOscillatorIndicator.up, a);
        }
        t9() {
            return this.longPeriod;
        }
    }
    AbsoluteVolumeOscillatorIndicator.$t = /*@__PURE__*/ markType(AbsoluteVolumeOscillatorIndicator, 'AbsoluteVolumeOscillatorIndicator', StrategyBasedIndicator.$, [IShortPeriodLongPeriod_$type]);
    AbsoluteVolumeOscillatorIndicator.uq = /*@__PURE__*/ StrategyBasedIndicator.uo(10, AbsoluteVolumeOscillatorIndicator.$);
    AbsoluteVolumeOscillatorIndicator.up = /*@__PURE__*/ StrategyBasedIndicator.uk(30, AbsoluteVolumeOscillatorIndicator.$);
    return AbsoluteVolumeOscillatorIndicator;
})();

==> igniteui-react-charts-16.16.3.tgz: package/esm2015/lib/AbsoluteVolumeOscillatorIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { IShortPeriodLongPeriod_$type } from "./IShortPeriodLongPeriod";
import { AbsoluteVolumeOscillatorIndicatorStrategy } from "./AbsoluteVolumeOscillatorIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core";
/**
 * @hidden
 */
export let AbsoluteVolumeOscillatorIndicator = /*@__PURE__*/ (() => {
    class AbsoluteVolumeOscillatorIndicator extends StrategyBasedIndicator {
        get_uh() {
            return new AbsoluteVolumeOscillatorIndicatorStrategy();
        }
        get uh() {
            return this.get_uh();
        }
        get_uu() {
            return AbsoluteVolumeOscillatorIndicator.$;
        }
        get uu() {
            return this.get_uu();
        }
        get shortPeriod() {
            return typeGetValue(this.c(AbsoluteVolumeOscillatorIndicator.u3));
        }
        set shortPeriod(a) {
            this.h(AbsoluteVolumeOscillatorIndicator.u3, a);
        }
        up() {
            return this.shortPeriod;
        }
        get longPeriod() {
            return typeGetValue(this.c(AbsoluteVolumeOscillatorIndicator.u2));
        }
        set longPeriod(a) {
            this.h(AbsoluteVolumeOscillatorIndicator.u2, a);
        }
        um() {
            return this.longPeriod;
        }
    }
    AbsoluteVolumeOscillatorIndicator.$t = /*@__PURE__*/ markType(AbsoluteVolumeOscillatorIndicator, 'AbsoluteVolumeOscillatorIndicator', StrategyBasedIndicator.$, [IShortPeriodLongPeriod_$type]);
    AbsoluteVolumeOscillatorIndicator.u3 = /*@__PURE__*/ StrategyBasedIndicator.u1(10, AbsoluteVolumeOscillatorIndicator.$);
    AbsoluteVolumeOscillatorIndicator.u2 = /*@__PURE__*/ StrategyBasedIndicator.ux(30, AbsoluteVolumeOscillatorIndicator.$);
    return AbsoluteVolumeOscillatorIndicator;
})();
